<?php

if (substr($messaggio,0,4) != "var_") {
switch ($messaggio) {

# translate YES and NO in upper case
case "SI":  					$messaggio = "SÍ"; break;
case "NO":  					$messaggio = "NO"; break;
case "Torna indietro":  			$messaggio = "Torna enrere"; break;
case "Crea pagine per il sito web":  		$messaggio = "Crea pàgines pel lloc web"; break;
case "Dati comuni":  				$messaggio = "Dades comunes"; break;
case "Utilizza i dati attuali per la connessione al database":	$messaggio = "Empra les dades actuals de connexió a la base de dades"; break;
case "Utilizza altri dati per la connessione al database":	$messaggio = "Empra noves dades de connexió a la base de dades"; break;
case "Tipo di database":  			$messaggio = "Tipus de base de dades"; break;
case "Postgresql":  				$messaggio = "PostgreSQL"; break;
case "Mysql":  					$messaggio = "MySQL"; break;
case "Nome del database da utilizzare":  	$messaggio = "Nom de la base de dades a utilitzar"; break;
case "Nome del computer a cui collegarsi":  	$messaggio = "Nom/IP de l'ordinador al qual connectar-se"; break;
case "Numero della porta a cui collegarsi":  	$messaggio = "Número de la port al qual connectar-se"; break;
case "Normalmete 5432 per Postgresql o 3306 per Mysql":	$messaggio = "Normalment 5432 per Postgresql o 3306 per Mysql"; break;
case "Nome per l'autenticazione al database":  	$messaggio = "Nom d'usuari per l'autenticació a la base de dades"; break;
case "Parola segreta per l'autenticazione al database":	$messaggio = "Contrasenya per l'autenticació a la base de dades"; break;
case "Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"":	$messaggio = "Carregar la llibreria dinàmica \"pgsql.so\" o \"mysql.so\""; break;
case "Si":  					$messaggio = "Sí"; break;
case "No":  					$messaggio = "No"; break;
case "scegliere si se non viene caricata automaticamente da php":	$messaggio = "cal escollir SÍ si la llibreria no fos carregada automàticament per PHP"; break;
case "Percorso alla directory dati da dove verrà posizionato lo script":	$messaggio = "Camí al directori dati relatiu al lloc on el desaran els models d'internet"; break;
case "solo per mysql":  			$messaggio = "només per MySQL"; break;
case "Anno":  					$messaggio = "any"; break;
case "Lingua":  				$messaggio = "Idioma"; break;
case "Formato di visualizzazione dei soldi":  	$messaggio = "Format de visualització de divises"; break;
case "Formato di visualizzazione delle date":  	$messaggio = "Format de visualització de dates"; break;
case "Nome della valuta al singolare":  	$messaggio = "Nom de la divisa al singular"; break;
case "Nome della valuta al plurale":  		$messaggio = "Nom de la divisa al plural"; break;
case "Pagina per la disponibilità":  		$messaggio = "Pàgina per la disponibilitat"; break;
case "Le date sono sbagliate":  		$messaggio = "Les dates són errònies"; break;
case "Indirizzo email non valido":  		$messaggio = "Adreça de correo electrònic invàlida"; break;
case "INIZIO VARIABILI MODIFICABILI":  		$messaggio = "COMENÇAMENT DE LES VARIABLES MODIFICABLES"; break;
case "Inserire in questa variabile il nome della pagina se \$PHP_SELF non è definita":	$messaggio = "Inserir el nom de la página en aquesta variable si \$PHP_SELF no fos definida"; break;
case "europa":  				$messaggio = "Europa"; break;
case "usa":  					$messaggio = "USA"; break;
case "FRASI":  					$messaggio = "FRASES"; break;
case "FRASI EMAIL":  				$messaggio = "FRASES CORREU ELECTRÒNIC"; break;
case "PERIODI NEI MENU":  			$messaggio = "PERIODES DELS MENÚS"; break;
case "FINE VARIABILI MODIFICABILI":  		$messaggio = "FINAL DE LES VARIABLES MODIFICABLES"; break;
case "NON MODIFICARE NIENTE A PARTIRE DA QUI":	$messaggio = "NO MODIFICAR RES A PARTIR D'AQUI"; break;
case "La variabile \\\$PHP_SELF non è definita, si dovrà editare a mano questa pagina per inserirne il nome":	$messaggio = "La variable \\\$PHP_SELF no és definida, caldrà editar manualment aquesta pàgina per inserir el nom"; break;
case "Non ho il permesso di scrittura nella cartella":	$messaggio = "No hi ha permís d'escriptura sobre el directori"; break;
case "OK":  					$messaggio = "OK"; break;
case "Pagina per controllare la disponibilità":	$messaggio = "Pàgina de cerca de disponibilitat"; break;
case "Date nei menù a tendina":  		$messaggio = "Dates de les llistes desplegables"; break;
case "Tariffe (tipologie) da mostrare ed eventuali loro nomi sostitutivi con cui mostrarle":	$messaggio = "Tarifes (tipologies) que es mostraran i llurs possibles noms de cares als visitants del web"; break;
case "col nome":  				$messaggio = "amb nom"; break;
case "Chiedere se aggiungere i costi presenti nella pagina di inserzione prenotazioni?":	$messaggio = "Demanar si cal afegir els costos presents a la pàgina d'inserció de reserves?"; break;
case "Aggiungere al prezzo i costi aggiuntivi fissi associati alle tariffe?":	$messaggio = "Afegir al preu els suplements fixes associats a les tarifes?"; break;
case "Costi aggiuntivi da mostrare ed eventuali loro nomi sostitutivi con cui mostrarli":	$messaggio = "Suplements que es mostraran i llurs noms de cares als visitants del web"; break;
case "Costo settimanale":  			$messaggio = "Cost semtanal"; break;
case "Costo unico":  				$messaggio = "Cost puntual"; break;
case "Costo giornaliero":  			$messaggio = "Cost diari"; break;
case "nessuna":  				$messaggio = "ninguna"; break;
case "comportati come se non vi fosse più disponibilità":	$messaggio = "comportar-se com si no hi hagués disponibilitat"; break;
case "dai ancora disponibilità con questa frase alternativa":	$messaggio = "ofereix disponibilitat amb aquesta frase alternativa"; break;
case "Disponibilità incerta per la tipologia scelta, per ulteriori informazioni contattateci via email":	$messaggio = "No ha estat possible determinar la disponibilitat per a la tipologia escollida. Si us plau, contacteu-nos per correu electrònic"; break;
case "Mostrare la caparra se presente?":  	$messaggio = "Mostrar les arres si fossin presents?"; break;
case "Mostrare quali sono i giorni pieni all'interno dei periodi dove non c'è più disponibilità?":	$messaggio = "Mostrar quins dies són plens dins del període demanat?"; break;
case "Mostrare la form di richiesta prenotazione?":	$messaggio = "Mostrar el formulari per demanar reservar?"; break;
case "Indirizzo email a cui inviare le richieste di prenotazione":	$messaggio = "Adreça d'email a la qual s'enviarà la petició de reserva"; break;
case "Mascherare la provenienza dell'email sull'envelope?":	$messaggio = "Enmascarar la provinença de l'email?"; break;
case "provare a cambiare se non si riescono a spedire le email":	$messaggio = "intentar camviar-lo si no fos possible enviar els emails"; break;
case "Tag html di apertura per la formattazione delle font":	$messaggio = "Element HTML d'obertura per formatar el tipus de lletra"; break;
case "Tag html di chiusura per la formattazione delle font":	$messaggio = "Element HTML de tancament per formatar el tipus de lletra"; break;
case "Tag html di apertura per la formattazione delle font rosse":	$messaggio = "Element HTML d'obertura per formatar el tipus de lletra en color vermell"; break;
case "Tag html di chiusura per la formattazione delle font rosse":	$messaggio = "Element HTML de tancament per formatar el tipus de lletra en color vermell"; break;
case "Crea la pagina per la disponibilità":  	$messaggio = "Crea la pàgina para cercar disponibilitat"; break;
case "Controlla la disponibilità":  		$messaggio = "Cerca disponibilitat"; break;
case "dal":  					$messaggio = "des del"; break;
case "al":  					$messaggio = "fins el"; break;
case "per la tipologia":  			$messaggio = "per la tipologia"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "per":  					$messaggio = "per"; break;
case "Le date sono sbagliate":  		$messaggio = "Les dates són errònies"; break;
case "La tipologia è sbagliata":  		$messaggio = "La tipologia és errònia"; break;
case "è":  					$messaggio = "és"; break;
case "pien":  					$messaggio = "ple"; break;
case "Non c'è più disponibilità nel periodo richiesto":	$messaggio = "No hi ha disponibilitat al període demanat"; break;
case "nel periodo richiesto":			$messaggio = "al període demanat"; break;
case "nei periodi richiesti":			$messaggio = "als períodes demanats"; break;
case "per la tipologia":			$messaggio = "per la tipologia"; break;
case "per le tipologie richieste":		$messaggio = "per les tipologies demanades"; break;
case "Non c'è più disponibilità":	$messaggio = "No queda disponibilitat"; break;
case "Periodo di":  				$messaggio = "Període de"; break;
case "Non c'è ancora nessuna tariffa per la tipologia richiesta in questo periodo":	$messaggio = "Encara no s'ha establert la tarifa per la tipologia demanada en aquest període"; break;
case "E' necessario inserire il numero di persone per questa tipologia":	$messaggio = "Cal inserir el número de persones per aquesta tipologia"; break;
case "Prezzo":  				$messaggio = "Preu"; break;
case "Caparra":  				$messaggio = "Arres"; break;
case "compresi":  				$messaggio = "inclosos"; break;
case "di":  					$messaggio = "de"; break;
case "Nuovo controllo":  			$messaggio = "Nova cerca"; break;
case "Nome":  					$messaggio = "Nom"; break;
case "Commento":  				$messaggio = "Comentari"; break;
case "Invia la richiesta di prenotazione":  	$messaggio = "Enviar sol·licitud de reserva"; break;
case "Richiesta di prenotazione inviata": 	$messaggio = "Sol·licitud de reserva enviada"; break;
case "Non è stato possibile inviare la richiesta":	$messaggio = "No ha estat possible enviar la sol·licitud de reserva"; break;
case "da":  					$messaggio = "des de"; break;
case "Periodo":  				$messaggio = "Període"; break;
case "Tariffa":  				$messaggio = "Tarifa"; break;
case "Costi aggiuntivi":  			$messaggio = "Suplements"; break;
case "Prezzo totale":  				$messaggio = "Preu total"; break;
case "Riferimento":  				$messaggio = "Referència"; break;
case "Richesta prenotazione":  			$messaggio = "Sol·licitud de reserva"; break;
case "modificare il valore sulla destra":  	$messaggio = "modificar el valor a la dreta"; break;
case "settimane":  				$messaggio = "semtanes"; break;
case "giorni":  				$messaggio = "dies"; break;
case "settimana":  				$messaggio = "semtana"; break;
case "giorno":  				$messaggio = "dia"; break;
case "La":  					$messaggio = "La"; break;
case "Il":  					$messaggio = "El"; break;
case "piena":  					$messaggio = "ple"; break;
case "pieno":  					$messaggio = "plena"; break;
case "Una pagina chiamata":  			$messaggio = "Una pàgina anomenada"; break;
case "è stata creata nella directory":  	$messaggio = "ha estat creada al directori"; break;
case "Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"":	$messaggio = "Pot canviar-se el directori on es creen les pàgines des de \"configurar i personalitzar\""; break;
case "INSERISCI QUI IL TUO HTML":  		$messaggio = "INSEREIX AQUI EL TEU HTML"; break;
case "FINE DELLA PRIMA PARTE DELL'HTML PERSONALE":	$messaggio = "FINAL DE LA PRIMERA PART DE L'HTML PERSONAL"; break;
case "INIZIO DELLA SECONDA PARTE DELL'HTML PERSONALE":	$messaggio = "PRINCIPI DE LA SEGONA PART DE L'HTML PERSONAL"; break;
case "FINE DELLA SECONDA PARTE DELL'HTML PERSONALE":	$messaggio = "FINAL DE LA SEGONA PART DE L'HTML PERSONAL"; break;
case "Prefisso nel nome delle tabelle":		$messaggio = "Prefix del nom de les taules"; break;
case "Parte html del file prima della form di disponibilità":	$messaggio = "Part html de l'arxiu abans del formulari de disponibilitat"; break;
case "Parte html del file dopo la form di disponibilità":	$messaggio = "Part html de l'arxiu després del formulari de disponibilitat"; break;
case "0 per scelta libera":  			$messaggio = "0 per opció lliure"; break;
case "Possibilità di aggiungere più tipologie da controllare contemporaneamente?":	$messaggio = "Posibilitat de cercar diverses tipologies simultàniament?"; break;
case "Numero massimo di tipologie":  		$messaggio = "Quantitat màxima de tipologies"; break;
case "Numero massimo di tipologie errato":  	$messaggio = "Quantitat màxima de tipologies errònia"; break;
case "Numero di":  				$messaggio = "Quantitat de"; break;
case "Il numero di":  				$messaggio = "La quantitat de"; break;
case "richiesto è sbagliato":  			$messaggio = "demanat és erroni"; break;
case "in":  					$messaggio = "a"; break;
case "Aggiungi una nuova tipologia":  		$messaggio = "Afegeix una tipologia nova"; break;
case "Numero di colonne dei costi aggiuntivi errato":	$messaggio = "Error en el número de columnes dels suplements"; break;
case "Numero di colonne dei costi aggiuntivi":	$messaggio = "Nombre de columnes dels suplements"; break;
case "tipologia":  				$messaggio = "tipologia"; break;
case "Elimina questa tipologia":  		$messaggio = "Elimina aquesta tipologia"; break;
case "Scegliere le settimane in cui applicare":	$messaggio = "Escollir les setmanes a les quals aplicar"; break;
case "Scegliere i giorni in cui applicare":  	$messaggio = "Escollir els dies als quals aplicar"; break;
case "Chiedere il numero di persone?":  	$messaggio = "Demanar el número de persones?"; break;
case "persone":  				$messaggio = "persones"; break;
case "Persone":  				$messaggio = "Persones"; break;
case "persona":  				$messaggio = "persona"; break;
case "Continua":  				$messaggio = "Continua"; break;
case "singolare":  				$messaggio = "singular"; break;
case "per ogni":  				$messaggio = "per cada"; break;
case "Si deve inserire il numero delle persone per":	$messaggio = "Cal inserir el número de persones per"; break;
case "Errore nei servizi opzionali richiesti":	$messaggio = "Error als serveis opcionals demanats"; break;
case "Numero massimo di persone":  		$messaggio = "Nombre màxim de persones"; break;
case "Se le persone superano la capienza massima utilizzare il costo aggiuntivo":	$messaggio = "Si les persones superessin la capacitat màxima emprar el suplement"; break;
case "Se il costo può essere moltiplicato aggiungere al massimo":	$messaggio = "Si el cost pot ésser multiplicat, afegir com a màxim"; break;
case "letti aggiuntivi":  			$messaggio = "llits addicionals"; break;
case "Numero massimo di persone errato":  	$messaggio = "Error en el número màxim de persones"; break;
case "Numero massimo di letti aggiuntivi errato":	$messaggio = "Error en el número màxim de llits addicionals"; break;
case "supera la capienza massima della tipologia richiesta":	$messaggio = "supera la capacitat màxima de la tipologia demanada"; break;
case "Si può creare un link verso questa pagina dal proprio sito internet":	$messaggio = "Es pot crear un enllaç cap a aquesta pàgina des del seu propi lloc web"; break;
case "Cancella":  				$messaggio = "Esborrar"; break;
case "tutte le pagine create":  		$messaggio = "totes les pàgines creades"; break;
case "Si è sicuri di voler <b style=\"color: red;\">cancellare</b>":	$messaggio = "Confirmi que cal <b style=\"color: red;\">esborrar</b>"; break;
case "la pagina":				$messaggio = "la pàgina"; break;
case "tutte le pagine create nella directory":	$messaggio = "totes les pàgines creades a la carpeta"; break;
case "tutte le pagine create nelle directory":	$messaggio = "totes les pàgines creades a les carpetes"; break;
case "Cancellate tutte le pagine":  		$messaggio = "Totes les pàgines han estat esborrades"; break;
case "OK":  					$messaggio = "OK"; break;
case "Modifica le frasi predefinite":  		$messaggio = "Modificar les frases predefinides"; break;
case "Frasi predefinite":  			$messaggio = "Frases predefinides"; break;
case "Mostrare il quadro indicativo della disponibilità?":	$messaggio = "Mostrar el quadre de disponibilitat?"; break;
case "Non mostrare":  				$messaggio = "No mostrar"; break;
case "Colore di sfondo della tabella":  	$messaggio = "Color de fons de la taula"; break;
case "Colore del giorno di inizio settimana":	$messaggio = "Color del dia d'inici de semtana"; break;
case "Colore dei periodi liberi":  		$messaggio = "Color dels períodes lliures"; break;
case "Colore dei periodi occupati":  		$messaggio = "Color dels períodes ocupats"; break;
case "Tag di apertura dei font della tabella":	$messaggio = "Element HTML d'obertura pel tipus de lletra de la taula"; break;
case "Tag di chiusura dei font della tabella":	$messaggio = "Element HTML de tancament pel tipus de lletra de la taula"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "Quadre de disponibilitat"; break;
case "Gennaio":  				$messaggio = "Gener"; break;
case "Febbraio":  				$messaggio = "Febrer"; break;
case "Marzo":  					$messaggio = "Març"; break;
case "Aprile":  				$messaggio = "Abril"; break;
case "Maggio":  				$messaggio = "Maig"; break;
case "Giugno":  				$messaggio = "Juny"; break;
case "Luglio":  				$messaggio = "Juliol"; break;
case "Agosto":  				$messaggio = "Agost"; break;
case "Settembre":  				$messaggio = "Septembre"; break;
case "Ottobre":  				$messaggio = "Octubre"; break;
case "Novembre":  				$messaggio = "Novembre"; break;
case "Dicembre":  				$messaggio = "Desembre"; break;
case "settimane di intervallo":  		$messaggio = "setmanes d'intèrval"; break;
case "giorni di intervallo":  			$messaggio = "dies d'intèrval"; break;
case "Estendere l'ultima data fino a quella massima disponibile nel database?":	$messaggio = "Estendre el rang de dates fins a l'última data disponible a la base de dades?"; break;
case "necessario":  				$messaggio = "necessari"; break;
case "opzionale":  				$messaggio = "opcional"; break;
case "non chiedere":  				$messaggio = "no demanar"; break;
case "Inviare la richiesta di prenotazione come messaggio a":	$messaggio = "Enviar la sol·licitud de reserva com a misstage a"; break;
case "Campi della form da chiedere":  		$messaggio = "Camps del formulari que haurà d'omplir l'usuari del web"; break;
case "Cognome":  				$messaggio = "Cognoms"; break;
case "Genere":  				$messaggio = "Gènere"; break;
case "Data di nascita":  			$messaggio = "Data de neixament"; break;
case "Nazione":  				$messaggio = "País"; break;
case "Città":  					$messaggio = "Ciutat"; break;
case "Regione":  				$messaggio = "Província"; break;
case "Via":  					$messaggio = "Carrer"; break;
case "Numero civico":  				$messaggio = "Número"; break;
case "Codice postale":  			$messaggio = "Codi postal"; break;
case "Telefono":  				$messaggio = "Telèfon"; break;
case "Secondo telefono":  			$messaggio = "Segon telèfon"; break;
case "Terzo telefono":  			$messaggio = "Tercer telèfon"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Orario stimato di arrivo":  		$messaggio = "Horario orientatiu d'arribada"; break;
case "Metodo di pagamento della caparra":  	$messaggio = "Mitjà de pagament de les arres"; break;
case "Metodi di pagamento della caparra da chiedere e loro eventuali nomi sostitutivi":	$messaggio = "Mitjans de pagament de la paaga i senyal i llurs noms amb els que es mostran al web"; break;
case "Campi della form personalizzati":  	$messaggio = "Camps personalitzats del formulari"; break;
case "tutti":  					$messaggio = "tots"; break;
case "<small>campi necessari</small>":		$messaggio = "<small>camps obligatoris</small>"; break;
case "M":  					$messaggio = "M"; break;
case "F":  					$messaggio = "F"; break;
case "Prenota":  				$messaggio = "Reservar"; break;
case "Mostrare il bottone per prenotare con la pagina di prenotazione immediata se presente?":	$messaggio = "Mostrar el botó de reservar amb la pàgina de reserva immediata si fos present?"; break;
case "Nome file della pagina di prenotazione immediata":	$messaggio = "Nom de l'arxiu de la pàgina de reserva immediata"; break;
case "--- OPPURE ---":  			$messaggio = "--- O ---"; break;
case "Prenotazione istantanea con PayPal":  	$messaggio = "Reservar immediatament amb PayPal"; break;
case "Accetta solo richieste che cominciano almeno dopo":	$messaggio = "Acceptar només consultes que comencin almenys després de"; $tr = 1; break;
case "Numero di settimane dopo cui prendere richieste errato":	$messaggio = "Error al número de setmanes després de les quals es pot reservar"; $tr = 1; break;
case "Numero di giorni dopo cui prendere richieste errato":	$messaggio = "Error al número de dies després dels quals es pot fer consultes"; $tr = 1; break;
case "Mostrare i calendari per la scelta delle date?":	$messaggio = "Mostrar els calendaris desplegables per escollir dates?"; break;
case "Stile riquadro calendario":  		$messaggio = "Estil requadre del calendari"; break;
case "Stile tabella calendario":  		$messaggio = "Estil taula calendari"; break;
case "Stile bottoni interni":  			$messaggio = "Estil botons interns"; break;
case "Stile bottone apertura":  		$messaggio = "Estil botó d'obertura"; break;
case "Colore date attive":  			$messaggio = "Color dates actives"; break;
case "Colore data selezionata":  		$messaggio = "Color dates seleccionades"; break;
case "Chiudi":  				$messaggio = "Tancar"; break;
case "mostra":  				$messaggio = "mostrar"; break;
case "non mostrare":  				$messaggio = "no mostrar"; break;
case "Inviare una copia della email di richiesta prenotazione al richiedente?":	$messaggio = "Enviar una còpia de l'email de la sol·licitud de reserva al sol·licitant?"; break;
case "Abbiamo ricevuto la sua richiesta di prenotazione e risponderemo al più presto possibile":	$messaggio = "Hem rebut la seva sol·licitud de reserva. L'atendrem en el més breu termini"; break;
case "Copia della richiesta è stata inviata a":	$messaggio = "Còpia de la sol·licitud ha estat enviada a"; break;
case "NON MODIFICARE MANUALMENTE":  		$messaggio = "NO MODIFICAR MANUALMENT"; break;
case "Anteporre il nome della valuta?":  	$messaggio = "Avantposar el nom de la divisa?"; break;
case "Stile della tabella che racchiude la form di prenotazione":	$messaggio = "Estil de la taula que contié el formulari de reserva"; break;
case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Aliniar la disponibilitat amb la data d'arribada?"; break;
case "Origine della prenotazione":  		$messaggio = "Origen de la reserva"; break;
case "Cartella":  				$messaggio = "Carpeta"; break;
case "Pagina cancellata":  			$messaggio = "Pàgina esborrada"; break;
case "Importa le pagine dalla cartella":  	$messaggio = "Importar les pàgines des de la carpeta"; break;
case "alla cartella":  				$messaggio = "a la carpeta"; break;
case "Importa":  				$messaggio = "Importar"; break;
case "Si è sicuri di voler importare le pagine dalla cartella":	$messaggio = "Segur que s'ha importar les pàgines des de la carpeta"; break;
case "eventuali pagine già presenti nella cartella":	$messaggio = "possibles pàgines preexistents a la carpeta"; break;
case "verranno <b style=\"font-weight: normal; color: red;\">sovrascritte</b>":	$messaggio = "seran <b style=\"font-weight: normal; color: red;\">sobreescrites</b>"; break;
case "Pagine importate":  			$messaggio = "Pàgines importades"; break;
case "con i servizi opzionali selezionati":  	$messaggio = "amb els serveis opcionals seleccionats"; break;
case "Utilizzare le liste di nazioni, regioni, etc. dell'utente":	$messaggio = "Emprar la llista de països, províncies, etc. de l'usuari"; break;
case "Url del file css per la modalità frame":	$messaggio = "URL de l'arxiu CSS per la modalitat FRAME"; break;
case "Utilizza per l'aspetto della pagina":  	$messaggio = "Emprar per l'aspecte de la pàgina"; break;
case "html personalizzato":  			$messaggio = "HTML personalitzat"; break;
case "il tema chiamato":  			$messaggio = "el tema anomenat"; break;
case "Colore del tema":  			$messaggio = "Color del tema"; break;
case "Data di arrivo":  			$messaggio = "Data d'arribada"; break;
case "Data di partenza":  			$messaggio = "Data de sortida"; break;
case "Tipologia":  				$messaggio = "Tipologia"; break;
case "default - frame orizzontale":  		$messaggio = "default - frame horitzontal"; break;
case "Condizioni da accettare nella form":  	$messaggio = "Condicions a acceptar al formulari"; break;
case "Accetto":  				$messaggio = "Accepto"; break;
case "larghezza":  				$messaggio = "amplada"; break;
case "altezza":  				$messaggio = "alçada"; break;
case "Dalla modalidà frame, aprire il secondo passo in una nuova finestra?":	$messaggio = "Des de la modalitat FRAME, obrir el segon pas en una finestra nova?"; break;
case "Geometria della nuova finestra":  	$messaggio = "Dimensions de la finestra nova"; break;
case "Torna alla HOME":  			$messaggio = "Tornar a HOME"; break;
case "URL della home":  			$messaggio = "URL de HOME"; break;
case "URL del logo":  				$messaggio = "URL del logotip"; break;
case "Valore del tema":  			$messaggio = "Valor del tema"; break;
case "Esempio di codice html per includere il primo passo della form in modalità frame su altre pagine del sito":	$messaggio = "Exemple de codi HTML per incloure al primer pas del formulari a la modalitat FRAME sobre d'altres pàgines del lloc web"; break;
case "selezionare \"html personalizzato\" nell'aspetto della pagina per modificarla":	$messaggio = "seleccionar \"html personalitzat\" a l'aspecte de la pàgina per modificar-la"; break;
case "Categoria":  				$messaggio = "Categoria"; break;
case "Attenzione":  				$messaggio = "Atenció"; break;
case "Motivazioni delle regole di assegnazone 1 per disponibilità condizionata da tenere in conto":	$messaggio = "Motivations of assignment rules 1 for conditional availability to consider"; break;
case "C'è ancora disponibilità":		$messaggio = "There is still availability"; break;
case "Email":  					$messaggio = "Email"; break;
case "Totale":  				$messaggio = "Total"; break;
case "Documento":  				$messaggio = "Document"; break;
case "<span style=\\\"color: red;\\\">*</span>":	$messaggio = "<span style=\\\"color: red;\\\">*</span>"; break;
case "<small>*</small>":  			$messaggio = "<small>*</small>"; break;
case "documento":  				$messaggio = "document"; break;
case "le regole 1 di chiusura vengono sempre applicate":	$messaggio = "rules 1 for closure are always applied"; break;
case "La tipologia richiesta è chiusa in questo periodo":	$messaggio = "The requested type is closed in this period"; break;
case "Spostamento orizzontale della posizione":	$messaggio = "Horizontal offset for position"; break;
case "nomi dall'utente delle liste":		$messaggio = "names from lists user"; break;
case "aggiunto al commento":  			$messaggio = "added to comment"; break;
case "aggiunto al campo":  			$messaggio = "added to field"; break;
case "del cliente":  				$messaggio = "in client data"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

# NAME OF THE FILE: same rules as varibles below
case "mdl_disponibilita":  			$messaggio = "mdl_disponibilitat"; break;

} # fine switch ($messaggio)
} # fine if (substr($messaggio,0,4) != "var_")


else {
switch ($messaggio) {

# NAMES OF VARIABLES: for translation leave the beginning as var_ and use only a-z, A-Z, 
# 0-9 and _ (underscore). No spaces, no accents! There must not be 2 with the same name.
# NOTE: names of variables are only shown when editing files, actually they don't need to be translated
case "var_nome_pagina":  			$messaggio = "var_nombre_pagina"; break;
case "var_anno":  				$messaggio = "var_agno"; break;
case "var_tipo_db":  				$messaggio = "var_tipo_db"; break;
case "var_nome_db":  				$messaggio = "var_nombre_db"; break;
case "var_computer_db":  			$messaggio = "var_ordenador_db"; break;
case "var_porta_db":  				$messaggio = "var_puerta_db"; break;
case "var_utente_db":  				$messaggio = "var_usuario_db"; break;
case "var_password_db":  			$messaggio = "var_contrasegna_db"; break;
case "var_carica_estensione_db":  		$messaggio = "var_carga_extension_db"; break;
case "var_prefisso_tabelle_db":  		$messaggio = "var_perefijo_tablas_db"; break;
case "var_lingua_modello":  			$messaggio = "var_idioma_modelo"; break;
case "var_cartella_mysql_lock":  		$messaggio = "var_directorio_mysql_lock"; break;
case "var_stile_soldi":  			$messaggio = "var_formato_dinero"; break;
case "var_stile_data":  			$messaggio = "var_formato_fechas"; break;
case "var_anteponi_nome_valuta":  		$messaggio = "var_anteponer_nombre_dinero"; break;
case "var_utente_liste":  			$messaggio = "var_usuario_listas"; break;
case "var_estendi_ultima_data":  		$messaggio = "var_ampliar_ultima_fecha"; break;
case "var_tariffe_mostra":  			$messaggio = "var_tarifas_a_ensegnar"; break;
case "var_nomi_tariffe_imposte":  		$messaggio = "var_nombres_tarifas_impuestas"; break;
case "var_aggiungi_costi_fissi":  		$messaggio = "var_agnade_costes_fijos"; break;
case "var_chiedi_costi_aggiuntivi_di_pag_inserzione":	$messaggio = "var_pregunta_costes_agnadidos_de_pag_insercion"; break;
case "var_costi_aggiuntivi_mostra":  		$messaggio = "var_costes_agnadidos_a_ensegnar"; break;
case "var_nomi_costi_agg_imposti":  		$messaggio = "var_nombres_costes_agnadidos_impuestos"; break;
case "var_categorie_costi_agg_imposte":  	$messaggio = "var_categorias_costes_agnadidos_impuestas"; break;
case "var_assegna_con_regola2":  		$messaggio = "var_asigna_con_regla1"; break;
case "var_considera_motivazioni_regola1":  	$messaggio = "var_considera_motivaciones_regla1"; break;
case "var_mostra_frase_alternativa_regola1":  	$messaggio = "var_muestra_frase_alternativa_regla1"; break;
case "var_mostra_caparra":  			$messaggio = "var_muestra_fianza"; break;
case "var_mostra_richiesta_via_mail":  		$messaggio = "var_muestra_pedido_por_mail"; break;
case "var_indirizzo_email":  			$messaggio = "var_direccion_email"; break;
case "var_maschera_email":  			$messaggio = "var_enmascara_email"; break;
case "var_mostra_giorni_pieni":  		$messaggio = "var_muestra_dias_llenos"; break;
case "var_mostra_bottone_paypal":  		$messaggio = "var_muestra_boton_paypal"; break;
case "var_nome_modello_paypal":  		$messaggio = "var_nombre_modelo_paypal"; break;
case "var_origine_prenotazione":  		$messaggio = "var_origen_reserva"; break;
case "var_apertura_tag_font":  			$messaggio = "var_apertura_elemento_letras"; break;
case "var_chiusura_tag_font":  			$messaggio = "var_cierre_elemento_letras"; break;
case "var_apertura_tag_font_rosse":  		$messaggio = "var_apertura_elemento_letras_rojas"; break;
case "var_chiusura_tag_font_rosse":  		$messaggio = "var_cierre_elemento_letras_rojas"; break;
case "var_chiedi_numero_persone":  		$messaggio = "var_pregunta_numero_personas"; break;
case "var_periodi_no_richieste":		$messaggio = "var_periodos_no_consultas"; break;
case "var_mostra_calendario_scelta_date":  	$messaggio = "var_muestra_calendario_escoger_fechas"; break;
case "var_stile_riquadro_calendario":  		$messaggio = "var_estilo_recuadro_calendario"; break;
case "var_stile_tabella_calendario":  		$messaggio = "var_estilo_tabla_calendario"; break;
case "var_stile_bottoni_calendario":  		$messaggio = "var_estilo_botones_calendario"; break;
case "var_stile_bottone_apertura_calendario":  	$messaggio = "var_estilo_boton_apertura_calendario"; break;
case "var_colore_data_attiva_calendario":  	$messaggio = "var_color_fecha_activa_calendario"; break;
case "var_colore_data_selezionata_calendario":	$messaggio = "var_color_fecha_seleccionada_calendario"; break;
case "var_stile_tabella_prenotazione":  	$messaggio = "var_estilo_tabla_reserva"; break;
case "var_file_css_frame":  			$messaggio = "var_archivo_css_frame"; break;
case "var_apri_nuova_finestra_da_frame":  	$messaggio = "var_abrir_nueva_ventana_desde_frame"; break;
case "var_larghezza_finestra_da_frame":  	$messaggio = "var_anchura_ventana_desde_frame"; break;
case "var_altezza_finestra_da_frame":  		$messaggio = "var_altura_ventana_desde_frame"; break;
case "var_tema_modello":  			$messaggio = "var_tema_modelo"; break;
case "var_colore_tema":  			$messaggio = "var_color_tema"; break;
case "var_valore_tema":  			$messaggio = "var_valor_tema"; break;
case "var_allinea_disponibilita_con_arrivo":	$messaggio = "var_alinear_disponibilidad_con_llegada"; break;
case "var_fr_Valuta_sing":  			$messaggio = "var_fr_divisa_sing"; break;
case "var_fr_Valuta_plur":  			$messaggio = "var_fr_divisa_plur"; break;
case "var_fr_Controlla_la_disponibilita":  	$messaggio = "var_fr_Controla_disponibilidad"; break;
case "var_fr_dal":  				$messaggio = "var_fr_desde"; break;
case "var_fr_al":  				$messaggio = "var_fr_hasta"; break;
case "var_fr_per_la_tipologia":  		$messaggio = "var_fr_para_la_tipologia"; break;
case "var_fr_tariffa":  			$messaggio = "var_fr_tarifa"; break;
case "var_fr_per":  				$messaggio = "var_fr_para"; break;
case "var_fr_Le_date_sono_sbagliate":  		$messaggio = "var_fr_Las_fechas_estan_equivocadas"; break;
case "var_fr_La_tipologia_e_sbagliata":  	$messaggio = "var_fr_La_tipologia_esta_equivocada"; break;
case "var_fr_parola_La":  			$messaggio = "var_fr_palabra_La"; break;
case "var_fr_parola_settimana":  		$messaggio = "var_fr_palabra_semana"; break;
case "var_fr_est":  				$messaggio = "var_fr_esta"; break;
case "var_fr_pien":  				$messaggio = "var_fr_llen"; break;
case "var_fr_lettera_a":  			$messaggio = "var_fr_letra_a"; break;
case "var_fr_Non_c_e_piu_disponibilita_nel_periodo_richiesto":	$messaggio = "var_fr_Ya_no_hay_mas_disponibilidad_en_el_periodo_pedido"; break;
case "var_fr_C_e_ancora_disponibilita":  	$messaggio = "var_fr_Todavia_hay_disponibilidad"; break;
case "var_fr_Non_c_e_piu_disponibilita":  	$messaggio = "var_fr_Ya_no_hay_mas_disponibilidad"; break;
case "var_fr_alternativa_regola1":  		$messaggio = "var_fr_alternativa_regla1"; break;
case "var_fr_Periodo_di":  			$messaggio = "var_fr_Periodo_de"; break;
case "var_fr_parola_settimane":  		$messaggio = "var_fr_palabra_semanas"; break;
case "var_fr_Non_c_e_tariffa_per_questa_tipologia_ecc":	$messaggio = "var_fr_Todavia_no_hay_ninguna_tarifa_para_la_tipologia_etc"; break;
case "var_fr_E_necessario_inserire_il_numero_di_persone_ecc":	$messaggio = "var_fr_Es_necesario_insertar_el_numero_de_personas_etc"; break;
case "var_fr_Prezzo":  				$messaggio = "var_fr_Precio"; break;
case "var_fr_Caparra":  			$messaggio = "var_fr_Fianza"; break;
case "var_fr_compresi":  			$messaggio = "var_fr_incluyendo"; break;
case "var_fr_di":  				$messaggio = "var_fr_de"; break;
case "var_fr_Nuovo_controllo":  		$messaggio = "var_fr_Nuevo_control"; break;
case "var_fr_Nome":  				$messaggio = "var_fr_Nombre"; break;
case "var_fr_Email":  				$messaggio = "var_fr_Email"; break;
case "var_fr_Commento":  			$messaggio = "var_fr_Comentario"; break;
case "var_fr_Invia_la_richiesta_di_prenotazione":	$messaggio = "var_fr_Envia_el_pedido_de_reserva"; break;
case "var_fr_Richiesta_di_prenotazione_inviata":	$messaggio = "var_fr_Pedido_de_reserva_enviado"; break;
case "var_fr_Non_e_stato_possibile_inviare_la_richiesta":	$messaggio = "var_fr_No_ha_sido_posible_enviar_el_pedido"; break;
case "var_fr_da":  				$messaggio = "var_fr_desde2"; break;
case "var_fre_Email":  				$messaggio = "var_fre_Email"; break;
case "var_fre_Nome":  				$messaggio = "var_fre_Nombre"; break;
case "var_fre_Commento":  			$messaggio = "var_fre_Comentario"; break;
case "var_fre_Periodo":  			$messaggio = "var_fre_Periodo"; break;
case "var_fre_dal":  				$messaggio = "var_fre_desde"; break;
case "var_fre_al":  				$messaggio = "var_fre_hasta"; break;
case "var_fre_Tariffa":  			$messaggio = "var_fre_Tarifa"; break;
case "var_fre_Costi_aggiuntivi":  		$messaggio = "var_fre_Costes_agnadidos"; break;
case "var_fre_sett":  				$messaggio = "var_fre_semanas"; break;
case "var_fre_Prezzo_totale":  			$messaggio = "var_fre_Precio_total"; break;
case "var_fre_Riferimento":  			$messaggio = "var_fre_Referencia"; break;
case "var_fre_Caparra":  			$messaggio = "var_fre_Fianza"; break;
case "var_fre_Richesta_prenotazione":  		$messaggio = "var_fre_Pedido_de_reserva"; break;
case "var_fr_Richesta_prenotazione":  		$messaggio = "var_fr_Pedido_de_reserva"; break;
case "var_periodi_menu":  			$messaggio = "var_lista_periodos"; break;
case "var_fr_appartamenti":  			$messaggio = "var_fr_apartamentos"; break;
case "var_fr_appartamento":  			$messaggio = "var_fr_apartamento"; break;
case "var_chiedi_numero_appartamenti_per_tipologia":	$messaggio = "var_pide_numero_apartamentos_por_tipologia"; break;
case "var_massimo_numero_appartamenti_per_tipologia":	$messaggio = "var_maximo_numero_apartamentos_por_tipologia"; break;
case "var_aggiungi_altre_tipologie":  		$messaggio = "var_agnade_otras_tipologias"; break;
case "var_massimo_numero_altre_tipologie":  	$messaggio = "var_maximo_numero_otras_tipologias"; break;
case "var_fr_Numero_di":  			$messaggio = "var_fr_Numero_de"; break;
case "var_fr_Il_numero_di":  			$messaggio = "var_fr_El_numero_de"; break;
case "var_fr_richiesto_e_sbagliato":  		$messaggio = "var_fr_pedido_esta_equivocado"; break;
case "var_fr_in":  				$messaggio = "var_fr_en"; break;
case "var_fr_Totale":  				$messaggio = "var_fr_Total"; break;
case "var_fre_Numero_di_appartamenti":  	$messaggio = "var_fre_Numero_de_apartamentos"; break;
case "var_fre_Persone":  			$messaggio = "var_fre_Personas"; break;
case "var_fr_Aggiungi_una_nuova_tipologia":	$messaggio = "var_fr_Agnade_una_nueva_tipologia"; break;
case "var_numero_colonne_costi_aggiuntivi":	$messaggio = "var_numero_columnas_costes_agnadidos"; break;
case "var_fr_per_la_tipologia":  		$messaggio = "var_fr_para_la_tipologia"; break;
case "var_fr_per_le_tipologie_richieste":  	$messaggio = "var_fr_para_las_tipologias_pedidas"; break;
case "var_fr_nel_periodo_richiesto":  		$messaggio = "var_fr_en_el_periodo_pedido"; break;
case "var_fr_nei_periodi_richiesti":  		$messaggio = "var_fr_en_los_periodos_pedidos"; break;
case "var_fr_tipologia":  			$messaggio = "var_fr_tipologia"; break;
case "var_fr_Torna_indietro":  			$messaggio = "var_fr_Vuelve_atras"; break;
case "var_fr_Elimina_questa_tipologia":  	$messaggio = "var_fr_Elimina_esta_tipologia"; break;
case "var_fr_Scegliere_le_settimane_in_cui_applicare":	$messaggio = "var_fr_Escoger_las_semanas_en_las_que_aplicar"; break;
case "var_fr_persone":  			$messaggio = "var_fr_personas"; break;
case "var_fr_persona":  			$messaggio = "var_fr_persona"; break;
case "var_fr_Continua":  			$messaggio = "var_fr_Continua"; break;
case "var_fr_per_ogni":  			$messaggio = "var_fr_para_cada"; break;
case "var_fr_Si_deve_inserire_il_numero_delle_persone_per":	$messaggio = "var_fr_Hay_que_insertar_el_numero_de_personas_para"; break;
case "var_fr_Errore_nei_servizi_opzionali_richiesti":	$messaggio = "var_fr_Error_en_los_servicios_opcionales_pedidos"; break;
case "var_massimo_numero_persone":  		$messaggio = "var_maximo_numero_personas"; break;
case "var_costo_aggiungi_letti":  		$messaggio = "var_coste_agnade_camas"; break;
case "var_massimo_numero_letti_aggiuntivi":  	$messaggio = "var_maximo_numero_camas_extra"; break;
case "var_fr_supera_la_capienza_massima_della_tipologia_richiesta":	$messaggio = "var_fr_supera_la_capacidad_maxima_de_la_tipologia_pedida"; break;
case "var_mostra_quadro_disponibilita":  	$messaggio = "var_ensegna_cuadro_disponibilidad"; break;
case "var_raggruppa_quadro_disponibilita_con_regola_2":	$messaggio = "var_agrupar_cuadro_disponibilidad_con_regla_2"; break;
case "var_raggruppa_quadro_disponibilita_con_persone":	$messaggio = "var_agrupar_cuadro_disponibilidad_con_personas"; break;
case "var_colore_sfondo_quadro_disponibilita":	$messaggio = "var_color_fondo_cuadro_disponibilidad"; break;
case "var_colore_inizio_settimana_quadro_disponibilita":	$messaggio = "var_color_inicio_semana_cuadro_disponibilidad"; break;
case "var_colore_libero_quadro_disponibilita":	$messaggio = "var_color_libre_cuadro_disponibilidad"; break;
case "var_colore_occupato_quadro_disponibilita":	$messaggio = "var_color_ocupado_cuadro_disponibilidad"; break;
case "var_apertura_font_quadro_disponibilita":	$messaggio = "var_apertura_elemento_letras_cuadro_disponibilidad"; break;
case "var_chiusura_font_quadro_disponibilita":	$messaggio = "var_cierre_elemento_letras_cuadro_disponibilidad"; break;
case "var_mostra_numero_liberi_quadro_disponibilita":	$messaggio = "var_ensegna_numero_libres_cuadro_disponibilidad"; break;
case "var_fr_Quadro_indicativo_disponibilita":	$messaggio = "var_fr_Cuadro_indicativo_disponibilidad"; break;
case "var_fr_Gennaio":  			$messaggio = "var_fr_Enero"; break;
case "var_fr_Febbraio":  			$messaggio = "var_fr_Febrero"; break;
case "var_fr_Marzo":  				$messaggio = "var_fr_Marzo"; break;
case "var_fr_Aprile":  				$messaggio = "var_fr_Abril"; break;
case "var_fr_Maggio":  				$messaggio = "var_fr_Mayo"; break;
case "var_fr_Giugno":  				$messaggio = "var_fr_Junio"; break;
case "var_fr_Luglio":  				$messaggio = "var_fr_Julio"; break;
case "var_fr_Agosto":  				$messaggio = "var_fr_Agosto"; break;
case "var_fr_Settembre":  			$messaggio = "var_fr_Septiembre"; break;
case "var_fr_Ottobre":  			$messaggio = "var_fr_Octubre"; break;
case "var_fr_Novembre":  			$messaggio = "var_fr_Noviembre"; break;
case "var_fr_Dicembre":  			$messaggio = "var_fr_Diciembre"; break;
case "var_utente_messaggio":  			$messaggio = "var_usuario_mensaje"; break;
case "var_chiedi_cognome":  			$messaggio = "var_pedir_apellido"; break;
case "var_chiedi_nome":  			$messaggio = "var_pedir_nombre"; break;
case "var_chiedi_email":  			$messaggio = "var_pedir_email"; break;
case "var_chiedi_sesso":  			$messaggio = "var_pedir_sexo"; break;
case "var_chiedi_datanascita":  		$messaggio = "var_pedir_fechanacimiento"; break;
case "var_chiedi_documento":  			$messaggio = "var_pedir_documento"; break;
case "var_chiedi_nazione":  			$messaggio = "var_pedir_nacion"; break;
case "var_chiedi_citta":  			$messaggio = "var_pedir_ciudad"; break;
case "var_chiedi_regione":  			$messaggio = "var_pedir_region"; break;
case "var_chiedi_via":  			$messaggio = "var_pedir_calle"; break;
case "var_chiedi_numcivico":  			$messaggio = "var_pedir_numerocasa"; break;
case "var_chiedi_cap":  			$messaggio = "var_pedir_codigopostal"; break;
case "var_chiedi_telefono":  			$messaggio = "var_pedir_telefono"; break;
case "var_chiedi_telefono2":  			$messaggio = "var_pedir_telefono2"; break;
case "var_chiedi_telefono3":  			$messaggio = "var_pedir_telefono3"; break;
case "var_chiedi_fax":  			$messaggio = "var_pedir_fax"; break;
case "var_chiedi_commento":  			$messaggio = "var_pedir_comentario"; break;
case "var_chiedi_oracheckin":  			$messaggio = "var_pedir_horaentrada"; break;
case "var_chiedi_metodopagamento":  		$messaggio = "var_pedir_metodopago"; break;
case "var_metodi_pagamento_da_chiedere":  	$messaggio = "var_metodos_pago_a_pedir"; break;
case "var_nomi_metodi_pagamento_imposti":  	$messaggio = "var_nombres_metodos_pago_impuestos"; break;
case "var_campi_form_personalizzati":  		$messaggio = "var_campos_formulario_personalizados"; break;
case "var_chiedi_campi_form_personalizzati":  	$messaggio = "var_pedir_campos_formulario_personalizados"; break;
case "var_campi_form_doc_condizioni":  		$messaggio = "var_campos_formulario_doc_condiciones"; break;
case "var_chiedi_campi_form_doc_condizioni":  	$messaggio = "var_pedir_campos_formulario_doc_condiciones"; break;
case "var_fr_Cognome":  			$messaggio = "var_fr_Apellido"; break;
case "var_fr_Genere":  				$messaggio = "var_fr_Genero"; break;
case "var_fr_Data_di_nascita":  		$messaggio = "var_fr_Fecha_de_nacimiento"; break;
case "var_fr_Documento":  			$messaggio = "var_fr_Documento"; break;
case "var_fr_Nazione":  			$messaggio = "var_fr_Nacion"; break;
case "var_fr_Citta":  				$messaggio = "var_fr_Ciudad"; break;
case "var_fr_Regione":  			$messaggio = "var_fr_Region"; break;
case "var_fr_Via":  				$messaggio = "var_fr_Calle"; break;
case "var_fr_Numero_civico":  			$messaggio = "var_fr_Numero_de_casa"; break;
case "var_fr_Codice_postale":  			$messaggio = "var_fr_Codigo_postal"; break;
case "var_fr_Telefono":  			$messaggio = "var_fr_Telefono"; break;
case "var_fr_Secondo_telefono":  		$messaggio = "var_fr_Segundo_telefono"; break;
case "var_fr_Terzo_telefono":  			$messaggio = "var_fr_Tercer_telefono"; break;
case "var_fr_Fax":  				$messaggio = "var_fr_Fax"; break;
case "var_fr_Orario_stimato_di_arrivo":  	$messaggio = "var_fr_Horario_estimativo_de_llegada"; break;
case "var_fr_Metodo_di_pagamento_della_caparra":	$messaggio = "var_fr_Metodo_de_pago_de_la_fianza"; break;
case "var_fre_Cognome":  			$messaggio = "var_fre_Apellido"; break;
case "var_fre_Genere":  			$messaggio = "var_fre_Genero"; break;
case "var_fre_Data_di_nascita":  		$messaggio = "var_fre_Fecha_de_nacimiento"; break;
case "var_fre_Documento":  			$messaggio = "var_fre_Documento"; break;
case "var_fre_Nazione":  			$messaggio = "var_fre_Nacion"; break;
case "var_fre_Citta":  				$messaggio = "var_fre_Ciudad"; break;
case "var_fre_Regione":  			$messaggio = "var_fre_Region"; break;
case "var_fre_Via":  				$messaggio = "var_fre_Calle"; break;
case "var_fre_Numero_civico":  			$messaggio = "var_fre_Numero_de_casa"; break;
case "var_fre_Codice_postale":  		$messaggio = "var_fre_Codigo_postal"; break;
case "var_fre_Telefono":  			$messaggio = "var_fre_Telefono"; break;
case "var_fre_Secondo_telefono":  		$messaggio = "var_fre_Segundo_telefono"; break;
case "var_fre_Terzo_telefono":  		$messaggio = "var_fre_Tercer_telefono"; break;
case "var_fre_Fax":  				$messaggio = "var_fre_Fax"; break;
case "var_fre_Orario_stimato_di_arrivo":  	$messaggio = "var_fre_Horario_estimativo_de_llegada"; break;
case "var_fre_Metodo_di_pagamento_della_caparra":	$messaggio = "var_fre_Metodo_de_pago_de_la_fianza"; break;
case "var_fr_campi_necessari":  		$messaggio = "var_fr_campos_necesarios"; break;
case "var_fr_piena":  				$messaggio = "var_fr_llena"; break;
case "var_fr_asterisco_rosso":  		$messaggio = "var_fr_asterisco_rojo"; break;
case "var_fr_asterisco_nero":  			$messaggio = "var_fr_asterisco_negro"; break;
case "var_fr_maschile":  			$messaggio = "var_fr_masculino"; break;
case "var_fr_femminile":  			$messaggio = "var_fr_femenino"; break;
case "var_fr_Prenota":  			$messaggio = "var_fr_Reservar"; break;
case "var_fr_OPPURE_linee":  			$messaggio = "var_fr_O_lineas"; break;
case "var_fr_Prenotazione_istantanea_con_PayPal":	$messaggio = "var_fr_Reservar_instantaneamente_con_PayPal"; break;
case "var_fr_Chiudi":  				$messaggio = "var_fr_Cerrar"; break;
case "var_fr_Abbiamo_ricevuto_la_sua_richiesta_di_prenotazione_ecc":	$messaggio = "var_fr_Hemos_recibido_su_pedido_de_reserva_etc"; break;
case "var_fr_Copia_della_richiesta_e_stata_inviata_a":	$messaggio = "var_fr_Copia_del_pedido_ha_sido_enviada_a"; break;
case "var_fr_con_i_servizi_opzionali_selezionati":	$messaggio = "var_fr_con_los_servicios_opcionales_seleccionados"; break;
case "var_fr_Data_di_arrivo":  			$messaggio = "var_fr_Fecha_de_llegada"; break;
case "var_fr_Data_di_partenza":  		$messaggio = "var_fr_Fecha_de_salida"; break;
case "var_fr_Tipologia":  			$messaggio = "var_fr_Tipologia"; break;
case "var_fr_Accetto":  			$messaggio = "var_fr_Acepto"; break;

case "var_spostamento_orizzontale_calendario":  $messaggio = "var_calendar_horizontal_offset"; break;
case "var_manda_copia_richiesta_email":  	$messaggio = "var_send_copy_of_request_email"; break;
case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_phr_The_requested_type_is_closed_in_this_period"; break;
case "var_":  		$messaggio = "var_"; break;
case "var_":  		$messaggio = "var_"; break;
case "var_ins_campi_form_personalizzati":  	$messaggio = "var_ins_custom_form_fields"; break;
} # fine switch ($messaggio)
} # fine else if (substr($messaggio,0,4) != "var_")



?>